==> RedeR_2.2.1.zip: RedeR/NEWS.Rd <==
\name{RedeR-News}
\title{RedeR News}
\encoding{UTF-8}

\section{Version 2.2.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 2.0.0}{
  \itemize{
    \item Major upgrade of the user interface.
  }
}

\section{Version 1.42.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.40.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.38.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.36.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.34.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.32.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.30.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.28.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.26.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.24.0}{
  \itemize{
    \item Implemented a new call-back method using R core infrastructure.
  }
}

\section{Version 1.22.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.20.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.18.0}{
  \itemize{
    \item Improved app reliability.
  }
}

\section{Version 1.16.0}{
  \itemize{
    \item Improved app reliability.
    \item Implemented new compatibility checks for call-back functions.
    \item Fix a client-server issue related with some MS-Windows specifications.
  }
}

\section{Version 1.14.0}{
  \itemize{
    \item Improved interface compatibility (call-back functions) for some Java platforms.
  }
}

\section{Version 1.12.0}{
  \itemize{
    \item Improved interactive layout algorithm.
    \item User interface is simplified, some shortcuts have been added.
    \item Final release cycle for some deprecated functions, moved to addGraph/getGraph related methods.
    \item Deprecated plugin builder methods have been removed.
  }
}

\section{Version 1.10.0}{
  \itemize{
    \item Improved graph attribute settings and interface.
  }
}

\section{Version 1.8.0}{
  \itemize{
    \item Improved compatibility with igraph objects.
    \item Additional arrow options to deal with directed graph associations.
  }
}

\section{Version 1.6.0}{
  \itemize{
    \item Interface simplification: several deprecated low-level functions have been moved to the addGraph/getGraph related methods.
    \item Dependence from igraph0 to igraph has been changed.
    \item Re-established connection with igraph.
  }
}

\section{Version 1.4.0}{
  \itemize{
    \item All graph attributes are now set via addGraph/getGraph methods.
    \item Improved loading performance: better xml serialization, data packing and post formats.
    \item Some routines have been simplified for better maintenance. 
  }
}

\section{Version 1.2.0}{
  \itemize{
    \item Improved loading performance, xml serialization, data packing and post formats.
    \item Improved server/client connection.
    \item Improved control over the app main features in R.
    \item Correction/fine-tune of dynamic layout function under zoom-in/zoom-out requests.
    \item Legend function is fixed for node/edge shape attributes.
  }
}

\section{Version 1.0.0}{
  \itemize{
    \item 1st release of RedeR [2011-03-23].
  }
}

==> RedeR_3.6.2.zip: RedeR/NEWS.Rd <==
\name{RedeR-News}
\title{RedeR News}
\encoding{UTF-8}

\section{Version 3.6.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 3.0.0}{
  \itemize{
    \item Major code refactoring.
    \item Improved readability.
    \item Reduced code complexities.
    \item Improved compatibility with standard base graphics.
  }
}

\section{Version 2.6.0}{
  \itemize{
    \item Major code refactoring.
    \item Improved readability.
    \item Reduced code complexities.
    \item Improved compatibility with standard igraph attributes.
  }
}

\section{Version 2.4.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 2.2.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 2.0.0}{
  \itemize{
    \item Major upgrade of the user interface.
  }
}

\section{Version 1.42.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.40.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.38.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.36.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.34.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.32.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.30.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.28.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.26.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.24.0}{
  \itemize{
    \item Implemented a new call-back method using R core infrastructure.
  }
}

\section{Version 1.22.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.20.0}{
  \itemize{
    \item Regular maintenance, stable release.
  }
}

\section{Version 1.18.0}{
  \itemize{
    \item Improved app reliability.
  }
}

\section{Version 1.16.0}{
  \itemize{
    \item Improved app reliability.
    \item Implemented new compatibility checks for call-back functions.
    \item Fix a client-server issue related with some MS-Windows specifications.
  }
}

\section{Version 1.14.0}{
  \itemize{
    \item Improved interface compatibility (call-back functions) for some Java platforms.
  }
}

\section{Version 1.12.0}{
  \itemize{
    \item Improved interactive layout algorithm.
    \item User interface is simplified, some shortcuts have been added.
    \item Final release cycle for some deprecated functions, moved to addGraph/getGraph related methods.
    \item Deprecated plugin builder methods have been removed.
  }
}

\section{Version 1.10.0}{
  \itemize{
    \item Improved graph attribute settings and interface.
  }
}

\section{Version 1.8.0}{
  \itemize{
    \item Improved compatibility with igraph objects.
    \item Additional arrow options to deal with directed graph associations.
  }
}

\section{Version 1.6.0}{
  \itemize{
    \item Interface simplification: several deprecated low-level functions have been moved to the addGraph/getGraph related methods.
    \item Dependence from igraph0 to igraph has been changed.
    \item Re-established connection with igraph.
  }
}

\section{Version 1.4.0}{
  \itemize{
    \item All graph attributes are now set via addGraph/getGraph methods.
    \item Improved loading performance: better xml serialization, data packing and post formats.
    \item Some routines have been simplified for better maintenance. 
  }
}

\section{Version 1.2.0}{
  \itemize{
    \item Improved loading performance, xml serialization, data packing and post formats.
    \item Improved server/client connection.
    \item Improved control over the app main features in R.
    \item Correction/fine-tune of dynamic layout function under zoom-in/zoom-out requests.
    \item Legend function is fixed for node/edge shape attributes.
  }
}

\section{Version 1.0.0}{
  \itemize{
    \item 1st release of RedeR [2011-03-23].
  }
}
